widgets

package module
v0.0.0-...-72758de Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	UPDATE_QUEUE_SIZE = 10
	POLLING_TIMEOUT   = 30
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AttributeSet

type AttributeSet struct {
	// contains filtered or unexported fields
}

func NewAttributeSet

func NewAttributeSet() *AttributeSet

func (*AttributeSet) Add

func (attrs *AttributeSet) Add(id, name, value string)

type RequestContext

type RequestContext struct {
	Request *api.WidgetRequest
	// contains filtered or unexported fields
}

func (*RequestContext) SendResponse

func (r *RequestContext) SendResponse(layout *string, attrs *AttributeSet, final bool) error

type Server

type Server struct {
	// contains filtered or unexported fields
}

func (*Server) Handle

func (s *Server) Handle(widgetName string, handler WidgetHandler)

func (*Server) ListenAndServe

func (s *Server) ListenAndServe(addr string) error

func (*Server) ServeHTTP

func (s *Server) ServeHTTP(w http.ResponseWriter, r *http.Request)

type WidgetHandler

type WidgetHandler func(ctx *RequestContext) error

Directories

Path Synopsis
Package core provides primitives to interact with the openapi HTTP API.
Package core provides primitives to interact with the openapi HTTP API.
cmd
widgetsrv command

Jump to